Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(13)

Unified Diff: chrome/browser/resources/media_router/media_router_data.js

Issue 1807223003: [Media Router WebUI] Clear pending route creation properties on error. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Changes per mfoltz@'s comments. Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/resources/media_router/elements/media_router_container/media_router_container.js ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/resources/media_router/media_router_data.js
diff --git a/chrome/browser/resources/media_router/media_router_data.js b/chrome/browser/resources/media_router/media_router_data.js
index f7e0a73abd0fe5b4783629e95f5b189a7b82ca4f..15b07e726c7acfd51d7f7a1dc1b492f5edb3cde6 100644
--- a/chrome/browser/resources/media_router/media_router_data.js
+++ b/chrome/browser/resources/media_router/media_router_data.js
@@ -120,7 +120,7 @@ cr.define('media_router', function() {
* @param {string} message The issue message.
* @param {number} defaultActionType The type of default action.
* @param {?number} secondaryActionType The type of optional action.
* @param {?string} mediaRouteId The route ID to which this issue
* pertains. If not set, this is a global issue.
* @param {boolean} isBlocking True if this issue blocks other UI.
* @param {?number} helpPageId The numeric help center ID.
@@ -128,7 +128,7 @@ cr.define('media_router', function() {
* @struct
*/
var Issue = function(id, title, message, defaultActionType,
- secondaryActionType, mediaRouteId, isBlocking,
+ secondaryActionType, routeId, isBlocking,
helpPageId) {
/** @type {string} */
this.id = id;
@@ -146,7 +146,7 @@ cr.define('media_router', function() {
this.secondaryActionType = secondaryActionType;
/** @type {?string} */
- this.mediaRouteId = mediaRouteId;
+ this.routeId = routeId;
/** @type {boolean} */
this.isBlocking = isBlocking;
« no previous file with comments | « chrome/browser/resources/media_router/elements/media_router_container/media_router_container.js ('k') | no next file » | no next file with comments »
@@ -120,7 +120,7 @@ cr.define('media_router', function() {
* @param {number} defaultActionType The type of default action.
* @param {?number} secondaryActionType The type of optional action.
- * @param {?string} mediaRouteId The route ID to which this issue
+ * @param {?string} routeId The route ID to which this issue
* pertains. If not set, this is a global issue.
* @param {boolean} isBlocking True if this issue blocks other UI.

Powered by Google App Engine
This is Rietveld 408576698